package Xchat::nocturne::NocKill;
use strict;
use warnings;
use Tie::File;

# REQUIRED FILE: noc.pl (in the same directory)

##############################################################################
#     NocKill      # Fancy way to kick, kill and kline.                      #
#        v1.4      # Developed and tested on Unreal ircd. Other ircds may    #
#################### require tiresome code modification at the commands      #
####################                                                         #
#   Aris Agrippas  # Every time you perform a /kill, /kick or /kline and you #
#     Copyright    # don't specify a reason, the reason is popped automati-  #
#       ©2007      # cally out from nockill.dat - a random BOFH excuse.      #
##############################################################################
# Warning: This works well on Unreal IRC servers. In case you're using it on #
# other protocols, please update as required.                                #
# Also keep in mind that Tie::File isn't dealing very well with Greek chars. #                    #
##############################################################################

my $def_ban_time = ' 2d '; # MUST be between spaces

my ($sname,$version) = ("nockill", "1.1");
Xchat::register($sname, $version, 
    "Enhanced /kill, /kick and /kline esp. for Unreal", "");

Xchat::print("\002\00304Noc\00310Kill\003\002 included");

Xchat::hook_command('KILL', 'kill' ,  
    {data => 'kill',  
     help_text => "USAGE: /kill user <reason>\n"});
Xchat::hook_command('KICK', 'kill' ,  
    {data => 'kick',  
     help_text => "USAGE: /kick user <reason>\n"});
Xchat::hook_command('KLINE', 'kline', 
    {data => 'kline', 
     help_text => "USAGE: /kline nick|host <time> <reason>\n"});

sub kill{
    return Xchat::EAT_NONE if ($#{$_[0]} == 0);
    my $command = $_[2]; # can either be kick or kill
    my $target = $_[0][1];
    if ($_[1][2] and $_[1][2] !~ /^[\s]*$/){
        Xchat::command($command . ' ' . $target . ' ' . $_[1][2]);
    } else {
        Xchat::command($command . ' ' . $target . ' ' . excuse());
    }
    return Xchat::EAT_ALL();
}

sub kline{
    my $arguments_size = $#{$_[0]};
    if ($arguments_size == 0) {return Xchat::EAT_NONE};
    
    my $target = $_[0][1];

    # if /kline is performed outside a channel, xchat gets fucked up
    # with user_info($target) so it's safer to use the nickname as 
    # the default hostmask:
    my $hostmask = $target;
    if (Xchat::user_info($target)){
        $hostmask = Xchat::Script::noc::getusername($target) 
        . '@' . Xchat::Script::noc::mask_host(Xchat::Script::noc::gethost($target));
    }
    
    if($arguments_size == 1){
        return Xchat::EAT_NONE if ($target =~ /^-.*/);
        Xchat::command('kline ' . $hostmask . $def_ban_time . excuse());
        return Xchat::EAT_ALL;
    } elsif($arguments_size == 2){
        my $dat = $_[0][2];
        return Xchat::EAT_NONE if ($target =~ /^-.*/);
        if (is_time($dat)){
            Xchat::command('kline ' . $hostmask . ' ' . $dat . ' ' . excuse());
        } else {
            Xchat::command('kline ' . $hostmask . $def_ban_time . $dat);
        }
        return Xchat::EAT_ALL;
    } elsif($arguments_size >= 3){
        my $dat = $_[1][2];
        return Xchat::EAT_NONE if ($target =~ /^-.*/);
        if (is_time($_[0][2])){
            Xchat::command('kline ' . $hostmask  . ' ' . $dat);
        } else {
            Xchat::command('kline ' . $hostmask . $def_ban_time . $dat);
        }
        return Xchat::EAT_ALL;
    } else {
        return Xchat::EAT_NONE;
    }
}

sub is_time{
    my $str = shift;
    my $bl_is_time = 0;
    if ($str =~ /^0$|^[[:digit:]]+[dhms]{1}$/){ $bl_is_time = 1}
    return $bl_is_time;
}

sub excuse{
    my $filename = Xchat::get_info('xchatdir') . "/" . $sname . ".dat";
    my $str = "";
    my $i = 0;
    tie my @datafile, 'Tie::File', $filename or die "Could not open file: " . $!;
    FILLSTR: while ($str =~ /^[\s]*$/) {
        $str = $datafile[ rand @datafile ];
        $i++;
        last LINE if ($i > 200);
    }
    untie @datafile;
    return $str;
}

